pub enum Status {
Initiated,
InProgress,
SellerRefunded,
Settled,
Released,
}Expand description
Lifecycle status of a Dispute.
Variants
Initiated
Dispute has been initiated and is waiting to be taken by a solver.
InProgress
A solver has taken the dispute and is working on it.
SellerRefunded
Admin/solver canceled the trade and refunded the seller.
Settled
Admin/solver settled the seller’s hold invoice and initiated payment to the buyer.
Released
The seller released the funds before the dispute was resolved.