RestoredDisputeHelper

Struct RestoredDisputeHelper 

pub struct RestoredDisputeHelper {
    pub dispute_id: Uuid,
    pub order_id: Uuid,
    pub dispute_status: String,
    pub master_buyer_pubkey: Option<String>,
    pub master_seller_pubkey: Option<String>,
    pub trade_index_buyer: Option<i64>,
    pub trade_index_seller: Option<i64>,
    pub buyer_dispute: bool,
    pub seller_dispute: bool,
    pub solver_pubkey: Option<String>,
}
Row-mapper used by mostrod when fetching disputes for session restore.

Field names are chosen to match the SQL SELECT aliases in the restore query (in particular status is aliased as dispute_status).

Fields

dispute_id: Uuid

Dispute id.

order_id: Uuid

Order id the dispute is attached to.

dispute_status: String

Dispute status, serialized as kebab-case.

master_buyer_pubkey: Option<String>

Master identity pubkey of the buyer, if any.

master_seller_pubkey: Option<String>

Master identity pubkey of the seller, if any.

trade_index_buyer: Option<i64>

Trade index the buyer used on the parent order.

trade_index_seller: Option<i64>

Trade index the seller used on the parent order.

buyer_dispute: bool

Whether the buyer has initiated a dispute for this order. Combined with Self::seller_dispute to derive RestoredDisputesInfo::initiator.

seller_dispute: bool

Whether the seller has initiated a dispute for this order. Combined with Self::buyer_dispute to derive RestoredDisputesInfo::initiator.

solver_pubkey: Option<String>

Public key of the solver assigned to the dispute, None if no solver has taken it.