Skip to main content Module message Copy item path Source MessageKind Use this Message to establish communication between users and Mostro PaymentFailedInfo Payment failure retry information Peer One party of the trade RestoreSessionInfo Restore session user info RestoredDisputeHelper Information about the dispute to be restored in the new client.
Note: field names are chosen to match expected SQL SELECT aliases in mostrod (e.g. status aliased as dispute_status). RestoredDisputesInfo Information about the dispute to be restored in the new client RestoredOrderHelper Helper struct for faster order-restore queries (used by mostrod).
Intended as a lightweight row-mapper when fetching restore metadata. RestoredOrdersInfo Information about the order to be restored in the new client Action Action is used to identify each message between Mostro and users DisputeInitiator Enum representing who initiated a dispute Message Use this Message to establish communication between users and Mostro Payload Message payload